@@ -7,7 +7,7 @@ use warnings;
 use Wx;
 use utf8;
 our $NAME = __PACKAGE__;
-our $VERSION = '0.6_89';
+our $VERSION = '0.6_91';
 
 use base qw/Wx::App/;
 use App::GUI::Cellgraph::Frame;
@@ -139,7 +139,7 @@ More details about this mechanics are to be found in the chapter
 =head2 General Settings
 
 =for HTML <p>
-<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Cellgraph/main/example/POD/GUIglobal7.png"   alt=""  width="630" height="410">
+<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Cellgraph/main/example/POD/GUIglobal7.png"   alt="" width="65%" height="65%">
 </p>
 
 The first tab contains settings, that shape the drawing in the most broad way.
@@ -239,7 +239,7 @@ a tile edge is long.
 =head2 Starting Row
 
 =for HTML <p>
-<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Cellgraph/main/example/POD/GUIstart7.png"   alt=""  width="630" height="410">
+<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Cellgraph/main/example/POD/GUIstart6.png" alt="" width="65%" height="65%">
 </p>
 
 This tab contains settings that define the start values - the states
@@ -270,7 +270,7 @@ previous start configuration.
 =head2 State Rules
 
 =for HTML <p>
-<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Cellgraph/main/example/POD/GUIrules.png"   alt=""  width="630" height="410">
+<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Cellgraph/main/example/POD/GUIrules7.png" alt="" width="65%" height="65%">
 </p>
 
 This tab contains settings that define the transfer function of cell states.
@@ -306,7 +306,7 @@ switch to zero and a state of 2 would not change because 4 - 2 = 2.
 =head2 Action Rules
 
 =for HTML <p>
-<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Cellgraph/main/example/POD/GUIaction.png"   alt=""  width="630" height="410">
+<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Cellgraph/main/example/POD/GUIaction7.png" alt="" width="65%" height="65%">
 </p>
 
 This tab parallels the previous even more, by also listing all subrules.
@@ -329,7 +329,7 @@ random amount.
 =head2 Colors
 
 =for HTML <p>
-<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Cellgraph/main/example/POD/GUIcolors.png"   alt=""  width="630" height="410">
+<img src="https://raw.githubusercontent.com/lichtkind/App-GUI-Cellgraph/main/example/POD/GUIcolors.png" alt="" width="65%" height="65%">
 </p>
 
 This panel helps you to customize the automaton/cell state colors, with
